@@ -72,6 +72,11 @@ class Util:
         command = ["git", "branch", "-d", BRANCH_NAME]
         self.execute_shell(command, False)
 
+    def reset_changes(self) -> None:
+        """Reset any noncommitted changes to the branch"""
+        command = ["git", "checkout", "."]
+        self.execute_shell(command, False)
+
     def push_dependency_update(self) -> None:
         """Git push any commits to remote"""
         if not self.push:
@@ -90,8 +95,8 @@ class Util:
         Returns False if there is not a major version bump
         Returns None if versions are not semver
         """
-        old_version_parsed = old_version.split(".")
-        new_version_parsed = new_version.split(".")
+        old_version_parsed = old_version.lstrip("^~ ").split(".")
+        new_version_parsed = new_version.lstrip("^~ ").split(".")
         if len(old_version_parsed) != 3 or len(new_version_parsed) != 3:
             return None
         try:
